BART-package modelsGet fitted draws from posterior of BART-package models
epred_draws_BART(
model,
newdata = NULL,
value = ".value",
...,
include_newdata = TRUE,
include_sigsqs = FALSE,
scale = "real"
)A tidy data frame (tibble) with fitted values.
A model from BART package.
Data frame to generate fitted values from. If omitted, defaults to the data used to fit the model.
The name of the output column for epred_draws; default ".value".
Arguments to pass to predict (e.g. BART:::predict.wbart).
Should the newdata be included in the tibble?
Should the posterior sigma-squared draw be included?
Should the fitted values be on the real, probit or logit scale?