bartCause-package objectsTypically referred to as fitted value draws on linear scale, where appropriate.
# S3 method for bartcFit
linpred_draws(
object,
...,
value = ".linpred",
re_formula = NULL,
fitstage = c("response", "assignment")
)A bartCauseFit object.
Additional arguments (e.g. newdata) passed to the underlying prediction method for the type of model given.
The name of the output column.
If NULL (default), include all group-level effects; if NA, include no group-level effects.
If is.null(type), return posterior from response or treatment assignment model.