stan4bart-package modelsTypically referred to as fitted value draws on linear scale, where appropriate.
# S3 method for stan4bartFit
linpred_draws(object, newdata, ..., value = ".linpred")A stan4bartFit object.
Data frame to generate predictions from [optional].
Additional arguments passed to the underlying prediction method for the type of model given.
The name of the output column.