lbart modelGet predict draws from posterior of lbart model
# S3 method for lbart
predicted_draws(
object,
newdata,
value = ".prediction",
...,
ndraws = NULL,
include_newdata = TRUE
)A tidy data frame (tibble) with predicted values.
A lbart model.
Data frame to generate predictions from. If omitted, most model types will generate predictions from the data used to fit the model.
The name of the output column for predicted_draws; default ".prediction".
Use to specify random number generator, default is rng=stats::rnorm.
Not currently implemented.
Should the newdata be included in the tibble?