pbart modelThe original response variable must be passed as an argument to this function. e.g. `response = y`
# S3 method for pbart
residual_draws(
object,
newdata,
value = ".residual",
...,
ndraws = NULL,
include_newdata = TRUE,
include_sigsqs = FALSE
)Tibble with residuals.
wbart model.
Data frame to generate predictions from. If omitted, original data used to fit the model.
Name of the output column for residual_draws; default is .residual.
Additional arguments passed to the underlying prediction method for the type of model given.
Not currently implemented.
Should the newdata be included in the tibble?
Should the posterior sigma-squared draw be included?