ATE = Average Treatment Effects Assumes treated column is either a integer column of 1's (treated) and 0's (nontreated) or logical indicating treatment if TRUE.
tidy_ate(model, treatment, common_support_method, cutoff, ...)A tidy data frame (tibble) with treatment effect values.
A supported Bayesian model fit that can provide fits and predictions.
A character string specifying the name of the treatment variable.
Either "sd", or "chisq". Default is unspecified, and no common support calculation is done.
Cutoff for common support (if in use).
Arguments to be passed to tidybayes::epred_draws typically scale for BART models.