CTE = Conditional Treatment Effects (usually used to generate (C)ATE or ATT)
newdata specifies the conditions, if unspecified it defaults to the original data.
Assumes treated column is either a integer column of 1's (treated) and 0's (nontreated) or logical indicating treatment if TRUE.
treatment_effects(
model,
treatment,
newdata,
subset = "all",
common_support_method,
cutoff,
...
)A tidy data frame (tibble) with treatment effect values.
A supported Bayesian model fit that can provide fits and predictions.
A character string specifying the name of the treatment variable.
Data frame to generate fitted values from. If omitted, defaults to the data used to fit the model.
Either "treated", "nontreated", or "all". Default is "all".
Either "sd", or "chisq". Default is unspecified, and no common support calculation is done.
Cutoff for common support (if in use).
Arguments to be passed to tidybayes::epred_draws typically scale for BART models.