stan4bart-package modelsGet prediction draws from posterior of stan4bart-package models
# S3 method for stan4bartFit
predicted_draws(
object,
newdata,
...,
value = ".prediction",
sample_new_levels = TRUE
)A stan4bartFit object.
Data frame to generate predictions from [optional].
Additional arguments passed to the underlying prediction method for the type of model given.
The name of the output column.
logical; if TRUE, levels out of the training sample will have random effects drawn from their posterior predictive distribution. If FALSE, their random effects will be fixed to 0.